.. _api-chapter:

===
API
===

Dennis is actually a library with a commandline interface
frontend. You can use the library without using the command line at
all.

This could be useful for linting strings on a translation system, etc.

This documentation needs to be written, but I'm going to wait until
the core stabilizies.
